# Annnotations_agreement
Implementation of popular agreement coefficients used for categorical measurements such as:
- Bennett et al.'s S score
- Cohen's kappa
- Gwet's gamma
- Krippendorff alpha
- Scott's pi

### Extended Formulas
All implementations are using extended formulas, which allows using:
- multiple raters
- multiple categories
- missing data

### Based on
All implementations were based on formulas available on https://github.com/jmgirard/mReliability/


